web\_payments\_dummy package
============================

Submodules
----------

web\_payments\_dummy.forms module
---------------------------------

.. automodule:: web_payments_dummy.forms
    :members:
    :undoc-members:
    :show-inheritance:

Module contents
---------------

.. automodule:: web_payments_dummy
    :members:
    :undoc-members:
    :show-inheritance:
